@@ -23,16 +23,21 @@ __copyright__ = "Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance
     "e" if sys.getfilesystemencoding() != "utf-8" else "\xe8"
 )
 __license__ = "GNU Lesser General Public License v3 or later (LGPLv3+)"
-__version__ = "0.7.1"
+__version__ = "0.7.2"
 
 from .api.errors import Error
-from .api.types.pyrogram import *
-from .client import ChatAction
-from .client import Client
-from .client import ParseMode
-from .client.input_media_photo import InputMediaPhoto
-from .client.input_media_video import InputMediaVideo
-from .client.input_phone_contact import InputPhoneContact
-from .client import Emoji
-from .client.handlers import MessageHandler, RawUpdateHandler
-from .client.filters import Filters
+from .client.types import (
+    Audio, Chat, ChatMember, ChatPhoto, Contact, Document, InputMediaPhoto,
+    InputMediaVideo, InputPhoneContact, Location, Message, MessageEntity,
+    PhotoSize, Sticker, Update, User, UserProfilePhotos, Venue, Video,
+    VideoNote, Voice, CallbackQuery
+)
+from .client.types.reply_markup import (
+    ForceReply, InlineKeyboardButton, InlineKeyboardMarkup,
+    KeyboardButton, ReplyKeyboardMarkup, ReplyKeyboardRemove
+)
+from .client import (
+    Client, ChatAction, ParseMode, Emoji,
+    MessageHandler, CallbackQueryHandler, RawUpdateHandler,
+    Filters
+)
